======
pyggcq
======

This is the documentation of **pyggcq**, a Scientific Python Package for G/G/c
Queueing Simulation

* **Release**: |release|
* **Date**: |today|
* **Author**: Andreas Sorge <as@asorge.de>
* **Documentation**: http://pyggcq.readthedocs.org
* **Repository**: http://github.com/andsor/pyggcq
* **PyPI**: `pypi.python.org/pypi/ggcq <https://pypi.python.org/pypi/ggcq>`_

Contents
========

.. toctree::
   :maxdepth: 2

   License <license>
   Module Reference <_rst/modules>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
